@@ -359,7 +359,7 @@ def decryptEmailToken(t):
 
 
 """
- Use phython's email package to get info out of the message.
+ Use python's email package to get info out of the message.
  Generally, an email is either 'multipart/alternative' (in which case it
  will have both a text and html subections representing different versions of
  the same message) or it will be a straight text
@@ -405,7 +405,7 @@ def extractMessageFromEmail(emailText):
 				html = unicode(part.get_payload(decode=True), str(charset), "ignore")
 
 	else:
-		textEmail = unicode(part.get_payload(decode=True), str(charset), "ignore")
+		textEmail = unicode(msg.get_payload(decode=True), str(charset), "ignore")
 
 	return textEmail, textSubject, emailFromAddress, emailToAddress
 
